@@ -56,7 +56,7 @@ DefaultAction.prototype.beginEvent = function() {
     this.d2Model = RVector.invalid;
     this.d2Screen = RVector.invalid;
     this.di = this.getDocumentInterface();
-    this.document = this.getDocument();
+    this.document = this.di.getDocument();
     this.setState(DefaultAction.State.Neutral);
     this.blockRefId = RObject.INVALID_ID;
     this.entityInBlockId = RObject.INVALID_ID;
@@ -141,7 +141,7 @@ DefaultAction.prototype.mouseMoveEvent = function(event) {
     if (event.buttons().valueOf() === Qt.MidButton.valueOf() ||
         (event.buttons().valueOf() === Qt.LeftButton.valueOf() &&
          event.modifiers().valueOf() === Qt.ControlModifier.valueOf())) {
-         return;
+        return;
     }
 
     var view, referencePoint, entityId, range;
@@ -416,6 +416,9 @@ DefaultAction.prototype.mouseDoubleClickEvent = function(event) {
         var strictRange = view.mapDistanceFromView(10);
         var entityId = this.di.getClosestEntity(event.getModelPosition(), range, strictRange, false);
         if (entityId===RObject.INVALID_ID) {
+            if (this.document.getCurrentViewportId()!==RObject.INVALID_ID) {
+                this.di.unsetCurrentViewport();
+            }
             return;
         }
 
@@ -549,6 +552,10 @@ DefaultAction.prototype.pickCoordinate = function(event, preview) {
  * Called when the mouse cursor hovers over an entity.
  */
 DefaultAction.prototype.highlightEntity = function(entityId) {
+    if (RSettings.getBoolValue("GraphicsView/HighlightEntity", true)===false) {
+        return;
+    }
+
     if (isNull(this.di)) {
         return;
     }
@@ -659,14 +666,19 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
 
         if (RSettings.getBoolValue("GraphicsView/DoubleClickSelectContour", true)===true) {
             include("scripts/Select/SelectContour/SelectContour.js");
-            var matchingEntities = SelectContour.getConnectedEntities(this.document, entityId, 0.001);
+            var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, 0.001);
             var add = (event.modifiers().valueOf() === Qt.ShiftModifier.valueOf());
             if (entity.isSelected()) {
-                this.di.selectEntities(matchingEntities, add);
+                this.di.selectEntities(matchingEntityIds, add);
             }
             else {
-                this.di.deselectEntities(matchingEntities);
+                this.di.deselectEntities(matchingEntityIds);
             }
         }
-    };
+    }
+
+    // TODO:
+//    else if (isViewportEntity(entity)) {
+//        this.di.setCurrentViewport(entity.data());
+//    }
 };
