@@ -21,7 +21,7 @@ include("WidgetFactory.js");
 include("scripts/Widgets/OptionsToolBar/OptionsToolBar.js");
 
 if (RSettings.isGuiEnabled()) {
-    if (new QFileInfo(autoPath("scripts/Widgets/CadToolBar/CadToolBar.js")).exists()) {
+    if (exists("scripts/Widgets/CadToolBar/CadToolBar.js")) {
         include("scripts/Widgets/CadToolBar/ColumnLayout.js");
         include("scripts/Widgets/CadToolBar/CadToolBar.js");
     }
@@ -58,6 +58,7 @@ function EAction(guiAction) {
 }
 
 EAction.prototype = new RActionAdapter();
+EAction.includeBasePath = includeBasePath;
 
 // some commonly used translated strings:
 EAction.trBack = qsTr("Back");
@@ -624,6 +625,10 @@ EAction.prototype.showDialog = function() {
 
     // sync invisible part of options tool bar with dialog:
     for (i=0; i<noSyncWidgets.length; i++) {
+        if (isDeleted(noSyncWidgets[i])) {
+            continue;
+        }
+
         noSyncWidgets[i].setProperty("Loaded", true);
     }
 
@@ -631,6 +636,10 @@ EAction.prototype.showDialog = function() {
     WidgetFactory.restoreState(optionsToolBar, this.settingsGroup, this);
 
     for (i=0; i<noSyncWidgets.length; i++) {
+        if (isDeleted(noSyncWidgets[i])) {
+            continue;
+        }
+
         noSyncWidgets[i].setProperty("Loaded", false);
     }
 
@@ -693,11 +702,13 @@ EAction.prototype.keyPressEvent = function(event) {
     }
 
     if ((event.key() >= Qt.Key_0.valueOf() && event.key() <= Qt.Key_9.valueOf()) || event.key() === Qt.Key_Period.valueOf()) {
-        // number or dot entered: give focus to first input widget in options tool bar and set text to number entered:
+        // number or dot entered:
+        // give focus to first input widget in options tool bar and set text to number entered:
         var w = OptionsToolBar.getFirstInputWidget();
         if (!isNull(w)) {
             w.setFocus(Qt.OtherFocusReason);
             w.text = String.fromCharCode(event.key());
+            event.accept();
             return;
         }
     }
@@ -720,15 +731,15 @@ EAction.prototype.setCrosshairCursor = function() {
     if (isNull(EAction.crossCursor)) {
         var bitmap, mask
         if (RSettings.getDevicePixelRatio()===2 && RS.getSystemId()!=="osx") {
-            bitmap = new QBitmap("scripts/CrosshairCursor@2x.png", "PNG");
-            mask = new QBitmap("scripts/CrosshairCursorMask@2x.png", "PNG");
+            bitmap = new QBitmap(EAction.includeBasePath + "/CrosshairCursor@2x.png", "PNG");
+            mask = new QBitmap(EAction.includeBasePath + "/CrosshairCursorMask@2x.png", "PNG");
             //bitmap.setDevicePixelRatio(2);
             //mask.setDevicePixelRatio(2);
             EAction.crossCursor = new QCursor(bitmap, mask, 15, 15);
         }
         else {
-            bitmap = new QBitmap("scripts/CrosshairCursor.png", "PNG");
-            mask = new QBitmap("scripts/CrosshairCursorMask.png", "PNG");
+            bitmap = new QBitmap(EAction.includeBasePath + "CrosshairCursor.png", "PNG");
+            mask = new QBitmap(EAction.includeBasePath + "CrosshairCursorMask.png", "PNG");
             EAction.crossCursor = new QCursor(bitmap, mask, 15, 15);
         }
     }
@@ -835,6 +846,7 @@ EAction.getMainWindow = function() {
 /**
  * Reactivates the main window after showing a dialog.
  * This is necessary with Qt>=5.
+ * Not necessary with Qt>=5.10.
  */
 EAction.activateMainWindow = function() {
 //    if (RSettings.isQt(5)) {
@@ -1073,7 +1085,9 @@ EAction.getToolBar = function(title, objectName, toolBarArea, category, before)
             }
         }
         tb.objectName = objectName;
-        tb.setProperty("Category", category);
+        if (!isNull(category)) {
+            tb.setProperty("Category", category);
+        }
         var s = RSettings.getIntValue("ToolBar/IconSize", tb.iconSize.width());
         tb.iconSize = new QSize(s,s);
         if (isNull(before)) {
