@@ -315,7 +315,21 @@ AbstractPreferences.prototype.load = function(addOn) {
         global[className].initPreferences(widget, true, document, this);
     }
 
-    WidgetFactory.restoreState(widget, undefined, undefined, false, document);
+    // check if preferences apply to block:
+    var store = document;
+    if (!this.appPreferences) {
+        var preferencesScope = "document";
+        if (!isNull(global[className]) && isFunction(global[className].getPreferencesScope)) {
+            if (document.getCurrentBlockId()!==document.getModelSpaceBlockId()) {
+                preferencesScope = global[className].getPreferencesScope();
+            }
+        }
+        if (!isNull(document) && preferencesScope==="block") {
+            store = document.queryCurrentBlock();
+        }
+    }
+
+    WidgetFactory.restoreState(widget, undefined, undefined, false, store);
 
     if (!isNull(global[className]) && isFunction(global[className].postInitPreferences)) {
         global[className].postInitPreferences(widget, true, document, this);
@@ -331,7 +345,7 @@ AbstractPreferences.prototype.save = function() {
     var transaction = undefined;
     if (!this.appPreferences) {
         document = EAction.getDocument();
-        transaction = new RTransaction(document.getStorage(), "Apply preferences", true);
+        transaction = new RTransaction(document.getStorage(), qsTr("Apply preferences"), true);
     }
 
     for (var i = 0; i < this.addOns.length; ++i) {
@@ -345,7 +359,26 @@ AbstractPreferences.prototype.save = function() {
         if (!isNull(global[className]) && isFunction(global[className].savePreferences)) {
             global[className].savePreferences(widget, true, document, transaction);
         }
-        WidgetFactory.saveState(widget, undefined, document);
+
+        // check if preferences apply to block:
+        var store = document;
+        var preferencesScope = "document";
+        if (!this.appPreferences) {
+            if (!isNull(global[className]) && isFunction(global[className].getPreferencesScope)) {
+                if (document.getCurrentBlockId()!==document.getModelSpaceBlockId()) {
+                    preferencesScope = global[className].getPreferencesScope();
+                }
+            }
+            if (!isNull(document) && preferencesScope==="block") {
+                store = document.queryCurrentBlock();
+            }
+        }
+        WidgetFactory.saveState(widget, undefined, store);
+        if (!this.appPreferences) {
+            if (preferencesScope==="block") {
+                transaction.addObject(store);
+            }
+        }
     }
 
     if (!this.appPreferences) {
