@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2016 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -58,7 +58,7 @@ function usage() {
           + "-enable-script-debugger          Enables the script debugger.\n"
           + "                                 NOT recommended as this may cause unexpected\n"
           + "                                 behavior when using QCAD.\n"
-          + "-debug-action-order              Print action oder information in menus\n"
+          + "-debug-action-order              Print action order information in menus\n"
           + "-exec [script file] [options]    Executes the given script file directly\n"
           + "                                 after staring QCAD. Options after the script\n"
           + "                                 file are passed on to the script.\n"
@@ -84,10 +84,12 @@ function usage() {
 }
 
 /**
- * Open files given as arguments args or creates a new document if
- * no files are given and createNew is true.
+ * Open files given as arguments args
+ *
+ * \param createNew Creates a new document if no files are given
+ * \param close Closes existing open MDI widgets
  */
-function openFiles(args, createNew) {
+function openFiles(args, createNew, close) {
     var appWin = RMainWindowQt.getMainWindow();
     if (isNull(appWin)) {
         // application is shutting down..
@@ -176,7 +178,12 @@ function openFiles(args, createNew) {
 
                 if (fileInfo.absoluteFilePath()===argFileInfo.absoluteFilePath()) {
                     mdiArea.setActiveSubWindow(mdiChildren[k]);
-                    foundExisting = true;
+                    if (close) {
+                        mdiArea.closeActiveSubWindow();
+                    }
+                    else {
+                        foundExisting = true;
+                    }
                     break;
                 }
             }
@@ -271,6 +278,7 @@ function setUpDragAndDrop(appWin) {
     });
 
     appWin.drop.connect(function(evt) {
+        // workaround for Qt keyboard focus bug:
         var appWin = RMainWindowQt.getMainWindow();
         if (!isNull(appWin)) {
             appWin.activateWindow();
@@ -304,6 +312,10 @@ function loadTranslations(addOns, splash) {
 
     // load C++ translations:
     var modules = ["qt", "assistant", "qt_help", "qcadcore", "qcadentity", "qcadgui"];
+    if (RSettings.isQt(5)) {
+        modules.unshift("qtbase");
+    }
+
     for (var mi=0; mi<modules.length; ++mi) {
         var module = modules[mi];
 
@@ -382,10 +394,10 @@ function initAddOns(addOns, splash) {
 }
 
 function postInitAddOns(addOns, splash) {
-    if (!isNull(splash)) {
-        splash.showMessage(qsTr("Post-initializing add-ons...") + "\n", Qt.AlignBottom);
-        QCoreApplication.processEvents();
-    }
+//    if (!isNull(splash)) {
+//        splash.showMessage(qsTr("Post-initializing add-ons...") + "\n", Qt.AlignBottom);
+//        QCoreApplication.processEvents();
+//    }
 
     var addOn;
     var i;
@@ -582,6 +594,7 @@ function main() {
 
         var pixmap = new QPixmap(fn);
         splash = new QSplashScreen(pixmap);
+        splash.objectName = "Splash";
         if (!QCoreApplication.arguments().contains("-no-show")) {
             splash.show();
         }
@@ -589,12 +602,18 @@ function main() {
 
     RFontList.initSubstitutions();
 
-    RPluginLoader.postInitPlugins(RPluginInterface.GotSplashWindow);
-
     // mark config file with current version number:
     var previousVersion = RSettings.getStringValue("Application/Version", "");
     RSettings.setValue("Application/Version", RSettings.getNumericalVersionString());
 
+    // save first start information:
+    RSettings.setFirstStart(isFirstStart);
+    // save new version information:
+    RSettings.setNewVersion(newVersion);
+    RSettings.setPreviousVersion(parseInt(previousVersion, 10));
+
+    RPluginLoader.postInitPlugins(RPluginInterface.GotSplashWindow);
+
     // scan for script add-ons (forced for first start, first start after
     // update, if configured):
     var addOns;
@@ -636,12 +655,6 @@ function main() {
     appWin.objectName = "MainWindow";
     appWin.windowTitle = qApp.applicationName;
 
-    // save first start information:
-    RSettings.setFirstStart(isFirstStart);
-    // save new version information:
-    RSettings.setNewVersion(newVersion);
-    RSettings.setPreviousVersion(parseInt(previousVersion, 10));
-
     // save locale
     appWin.setProperty("Locale", RSettings.getLocale());
     
@@ -695,14 +708,14 @@ function main() {
         appWin.show();
     }
 
-    postInitAddOns(addOns, splash);
-    RPluginLoader.postInitPlugins(RPluginInterface.GotMainWindow);
-
     if (!isNull(splash)) {
         splash.close();
         splash.destroy();
     }
 
+    postInitAddOns(addOns);
+    RPluginLoader.postInitPlugins(RPluginInterface.GotMainWindow);
+
     // if the window position / size was not read from a config file,
     // automatically position property editor and library browser (first start):
     if (isFirstStart) {
@@ -736,7 +749,9 @@ function main() {
     // open files given on command line:
     var clickedFilesAndArgs = filesToOpen.concat(args.slice(1));
     QCoreApplication.processEvents();
+    appWin.setProperty("starting", true);
     openFiles(clickedFilesAndArgs, !recovered);
+    appWin.setProperty("starting", false);
 
     RPluginLoader.postInitPlugins(RPluginInterface.LoadedFiles);
 
